@@ -13,20 +13,23 @@
 # limitations under the License.
 
 """Structures to offer storage to the charm (through Juju or locally)."""
-
+import logging
+import os
 import pickle
 import shutil
 import sqlite3
 import subprocess
 import typing
 from datetime import timedelta
+from pathlib import Path
 from typing import Any, Callable, Generator, List, Optional, Tuple, Type, Union
 
-import yaml
+import yaml  # pyright: reportMissingModuleSource=false
+
+logger = logging.getLogger()
+
 
 if typing.TYPE_CHECKING:
-    from pathlib import Path
-
     # _Notice = Tuple[event_path, observer_path, method_name]
     _Notice = Tuple[str, str, str]
     _Notices = List[_Notice]
@@ -42,7 +45,7 @@ def _run(args: List[str], **kw: Any):
     cmd = shutil.which(args[0])  # type: Optional[str]
     if cmd is None:
         raise FileNotFoundError(args[0])
-    return subprocess.run([cmd, *args[1:]], **kw)
+    return subprocess.run([cmd, *args[1:]], encoding='utf-8', **kw)
 
 
 class SQLiteStorage:
@@ -53,6 +56,11 @@ class SQLiteStorage:
     def __init__(self, filename: Union['Path', str]):
         # The isolation_level argument is set to None such that the implicit
         # transaction management behavior of the sqlite3 module is disabled.
+
+        if not os.path.exists(str(filename)):
+            # sqlite3.connect creates the file silently if it does not exist
+            logger.debug("Initializing SQLite local storage: {}.".format(filename))
+
         self._db = sqlite3.connect(str(filename),
                                    isolation_level=None,
                                    timeout=self.DB_LOCK_TIMEOUT.total_seconds())
@@ -350,7 +358,8 @@ class _JujuStorageBackend:
         # have the same default style.
         encoded_value = yaml.dump(value, Dumper=_SimpleDumper, default_flow_style=None)
         content = yaml.dump(
-            {key: encoded_value}, encoding='utf8', default_style='|',
+            {key: encoded_value},
+            default_style='|',
             default_flow_style=False,
             Dumper=_SimpleDumper)
         _run(["state-set", "--file", "-"], input=content, check=True)
@@ -364,7 +373,7 @@ class _JujuStorageBackend:
             CalledProcessError: if 'state-get' returns an error code.
         """
         # We don't capture stderr here so it can end up in debug logs.
-        p = _run(["state-get", key], stdout=subprocess.PIPE, check=True, universal_newlines=True)
+        p = _run(["state-get", key], stdout=subprocess.PIPE, check=True)
         if p.stdout == '' or p.stdout == '\n':
             raise KeyError(key)
         return yaml.load(p.stdout, Loader=_SimpleLoader)  # type: ignore
