@@ -21,7 +21,6 @@ import re
 import shutil
 import sys
 import tempfile
-import unittest
 from pathlib import Path
 from test.test_helpers import BaseTestCase, fake_script
 from unittest.mock import patch
@@ -547,7 +546,7 @@ class TestFramework(BaseTestCase):
             class OtherEvents(ObjectEvents):
                 foo = event
         self.assertEqual(
-            str(cm.exception),
+            str(cm.exception.__cause__),
             "EventSource(MyEvent) reused as MyEvents.foo and OtherEvents.foo")
 
         with self.assertRaises(RuntimeError) as cm:
@@ -555,7 +554,7 @@ class TestFramework(BaseTestCase):
                 on = MyEvents()
                 bar = event
         self.assertEqual(
-            str(cm.exception),
+            str(cm.exception.__cause__),
             "EventSource(MyEvent) reused as MyEvents.foo and MyNotifier.bar")
 
     def test_reemit_ignores_unknown_event_type(self):
@@ -1545,7 +1544,6 @@ class BreakpointTests(BaseTestCase):
             framework.breakpoint()
             self.assertEqual(fake_stderr.getvalue(), _BREAKPOINT_WELCOME_MESSAGE)
 
-    @unittest.skipIf(sys.version_info < (3, 7), "no breakpoint builtin for Python < 3.7")
     def test_breakpoint_builtin_sanity(self, fake_stderr):
         # this just checks that calling breakpoint() works as expected
         # nothing really framework-dependent
@@ -1555,12 +1553,11 @@ class BreakpointTests(BaseTestCase):
 
         with patch('pdb.Pdb.set_trace') as mock:
             this_frame = inspect.currentframe()
-            breakpoint()        # noqa: F821 ('undefined name' in <3.7)
+            breakpoint()
 
         self.assertEqual(mock.call_count, 1)
         self.assertEqual(mock.call_args, ((this_frame,), {}))
 
-    @unittest.skipIf(sys.version_info < (3, 7), "no sys.breakpointhook for Python < 3.7")
     def test_builtin_breakpoint_hooked(self, fake_stderr):
         # Verify that the proper hook is set.
         with patch.dict(os.environ, {'JUJU_DEBUG_AT': 'all'}):
@@ -1568,10 +1565,9 @@ class BreakpointTests(BaseTestCase):
         old_breakpointhook = framework.set_breakpointhook()
         self.addCleanup(setattr, sys, 'breakpointhook', old_breakpointhook)
         with patch('pdb.Pdb.set_trace') as mock:
-            breakpoint()        # noqa: F821 ('undefined name' in <3.7)
+            breakpoint()
         self.assertEqual(mock.call_count, 1)
 
-    @unittest.skipIf(sys.version_info < (3, 7), "no breakpoint builtin for Python < 3.7")
     def test_breakpoint_builtin_unset(self, fake_stderr):
         # if no JUJU_DEBUG_AT, no call to pdb is done
         with patch.dict(os.environ):
@@ -1581,7 +1577,7 @@ class BreakpointTests(BaseTestCase):
         self.addCleanup(setattr, sys, 'breakpointhook', old_breakpointhook)
 
         with patch('pdb.Pdb.set_trace') as mock:
-            breakpoint()        # noqa: F821 ('undefined name' in <3.7)
+            breakpoint()
 
         self.assertEqual(mock.call_count, 0)
 
